@@ -75,6 +75,8 @@ class Weatherbit:
         items = []
         for row in json_data["data"]:
             item = {
+                "language": self._language,
+                "units": self._units,
                 "station": row["station"],
                 "ob_time": row["ob_time"],
                 "datetime": row["datetime"],
