@@ -1,5 +1,8 @@
 from datetime import datetime as dt
 from dateutil import tz
+from weatherbitpypi.const import SUPPORTED_LANGUAGES
+import json
+import os
 
 """Defines the Data Classes used."""
 
@@ -34,6 +37,8 @@ class CurrentData:
         self._timezone = data["timezone"]
         self._sunrise = data["sunrise"]
         self._sunset = data["sunset"]
+        self._units = data["units"]
+        self._language = data["language"]
 
     @property
     def station(self) -> str:
@@ -98,7 +103,9 @@ class CurrentData:
     @property
     def wind_cdir(self) -> str:
         """Abbreviated wind direction.."""
-        return self._wind_cdir
+        direction_array = ["N","NNE","NE","ENE","E","ESE","SE","SSE","S","SSW","SW","WSW","W","WNW","NW","NNW","N"]
+        direction = direction_array[int((self._wind_dir + 11.25) / 22.5)]
+        return get_localized_text(self._language, direction, "wind_dir")
 
     @property
     def wind_dir(self) -> int:
@@ -195,6 +202,65 @@ class CurrentData:
 
         return obs_local.strftime("%Y-%m-%d %H:%M")
 
+    @property
+    def beaufort_value(self) -> int:
+        """Return the beaufort value based on current Wind Speed."""
+        if self._units != "M":
+            wind_speed_ms = self.wind_spd * 0.44704
+        else:
+            wind_speed_ms = self.wind_spd
+        
+        if (wind_speed_ms >= 32.6):
+            return 12
+        elif (wind_speed_ms >= 28.4):
+            return 11
+        elif (wind_speed_ms >= 24.5):
+            return 10
+        elif (wind_speed_ms >= 20.7):
+            return 9
+        elif (wind_speed_ms >= 17.2):
+            return 8
+        elif (wind_speed_ms >= 13.9):
+            return 7
+        elif (wind_speed_ms >= 10.8):
+            return 6
+        elif (wind_speed_ms >= 8.0):
+            return 5
+        elif (wind_speed_ms >= 5.5):
+            return 4
+        elif (wind_speed_ms >= 3.3):
+            return 3
+        elif (wind_speed_ms >= 1.5):
+            return 2
+        elif (wind_speed_ms >= 0.3):
+            return 1
+        else:
+            return 0
+
+    @property
+    def beaufort_text(self) -> str:
+        """Return Beaufort Description based on current wind speed."""
+        return get_localized_text(self._language, self.beaufort_value, "beaufort")
+
+
+def get_localized_text(language, value, index):
+    """Read the localized string from the Language file."""
+    if language not in SUPPORTED_LANGUAGES:
+        filename = f"/translations/en.json"
+    else:
+        filename = f"/translations/{language}.json"
+
+    # Build filepath
+    cwd = __file__
+    path_index = cwd.rfind("/")
+    top_path = cwd[0:path_index]
+    filepath = f"{top_path}{filename}"
+
+    # Return Value from language string
+    with open(filepath) as json_file:
+        data = json.load(json_file)
+        return data[index][str(value)]
+
 class ForecastDailyData:
     """A representation of Daily Forecast Weather Data."""
 
